/*
 * Copyright (c) 2009 Sun Microsystems, Inc.
 * All rights reserved.
 * Use is subject to license terms.
 */
package com.sun.jcconnected.clients.transit;

/**
 * The constants used by the <em>Transit Turnstile</code> terminal applications.
 * 
 * Note: this interface could also be used by the <em>Transit Tursntile</em> applet itself.
 */
public interface Constants {

    /**
     * CLA value for ISO 7816-4 commands.
     */
    byte CLA_ISO7816 = (byte) 0x00;

    /**
     * CLA value for <em>Transit Turnstile</em> applet-specific commands.
     */
    byte TRANSIT_CLA = (byte) 0x80;

    // Codes of INS byte in the command APDU header

    /**
     * INS value for ISO 7816-4 VERIFY command.
     */
    byte INS_VERIFY = (byte) 0x20;

    /**
     * INS value for ISO 7816-4 SELECT command.
     */
    byte INS_SELECT = (byte) 0XA4;

    /**
     * INS value for INITIALIZE_SESSION command.
     */
    byte INITIALIZE_SESSION = (byte) 0x30;

    /**
     * INS value for PROCESS_REQUEST command.
     */
    byte PROCESS_REQUEST = (byte) 0x40;

    // Tags for TLV records in PROCESS_REQUEST C-APDU

    /**
     * TLV Tag for PROCESS_ENTRY request.
     */
    byte PROCESS_ENTRY = (byte) 0xC1;

    /**
     * TLV Tag for PROCESS_EXIT request.
     */
    byte PROCESS_EXIT = (byte) 0xC2;

    /**
     * TLV Tag for GET_BALANCE request.
     */
    byte GET_BALANCE = (byte) 0xC4;

    /**
     * TLV Tag for PROCESS_LET_THROUGH request.
     */
    byte PROCESS_LET_THROUGH = (byte) 0xC3;

    /**
     * SW bytes for success.
     */
    int SW_NO_ERROR = 0x9000;

    /**
     * Unique ID length.
     */
    short UID_LENGTH = (short) 8;

    /**
     * Host and card challenge length.
     */
    short CHALLENGE_LENGTH = (short) 4;

    /**
     * MAC length as generated by Signature.ALG_DES_MAC8_ISO9797_M2.
     */
    short MAC_LENGTH = (short) 8;

    /**
     * DES key length in bytes.
     */
    int LENGTH_DES_BYTE = 8;

    /**
     * The default host name where the <em>jcre</em> is running.
     */
    String DEFAULT_HOST_NAME = "localhost";

    /**
     * The default port the <em>jcre</em> is listening on.
     */
    int DEFAULT_PORT = 9025;

    /**
     * The AID for the <em>Transit Turnstile</em> applet.
     */
    byte[] AID_TRANSIT = { (byte) 0xa0, (byte) 0x0, (byte) 0x0, (byte) 0x0,
            (byte) 0x62, (byte) 0x3, (byte) 0x1, (byte) 0xc, (byte) 0xD,
            (byte) 0x2 };

    /**
     * Boolean is set to indicate cryptography support in RI.
     */
    final static boolean CRYPTO_ENABLED = Boolean.FALSE;

}
